==> gtk+-1.1.0.tar.gz: gtk+-1.1.0/gtk/gtkfeatures.h <==
/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GTK_FEATURES_H__
#define __GTK_FEATURES_H__


#ifdef __cplusplus
extern "C" {
#pragma }
#endif /* __cplusplus */


/* compile time version
 */
#define GTK_MAJOR_VERSION				(1)
#define GTK_MINOR_VERSION				(1)
#define GTK_MICRO_VERSION				(0)
#define GTK_BINARY_AGE					(0)
#define GTK_INTERFACE_AGE				(0)

/* new gtk_container_set_focus_[hv]adjustment()
 */
#define GTK_HAVE_CONTAINER_FOCUS_ADJUSTMENTS		1-0-1

/* newly exported gtk_signal_init()
 * new gtk_signal_n_emissions*()
 * "signal-name" is now an alias for "signal_name"
 * new gtk_signal_emitv*()
 */
#define GTK_HAVE_SIGNAL_INIT				1-0-2
  
/* Gtk+ 1.1.0 version tag.
 * - new gtk_rc_set_image_loader () to install custom image loaders for rc
 *   files.
 * - GtkAccel groups replaced GtkAcceleratorTables
 * - Gdk supports full crossing event now.
 * - Buttons featur relief styles now.
 * - gdk_rgb_*() functions are in place.
 * - stringified enum values can be queried for enum types now.
 * - new key binding system is in place (GtkBindingSet).
 * - simple algorithm for pattern matching is expoted now (GtkPatternSpec).
 */
#define GTK_HAVE_FEATURES_1_1_0				1-1-0



#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GTK_FEATURES_H__ */

==> gtk+-1.1.3.tar.gz: gtk+-1.1.3/gtk/gtkfeatures.h <==
/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GTK_FEATURES_H__
#define __GTK_FEATURES_H__


#ifdef __cplusplus
extern "C" {
#pragma }
#endif /* __cplusplus */


/* compile time version
 */
#define GTK_MAJOR_VERSION				(1)
#define GTK_MINOR_VERSION				(1)
#define GTK_MICRO_VERSION				(3)
#define GTK_BINARY_AGE					(0)
#define GTK_INTERFACE_AGE				(0)

/* new gtk_container_set_focus_[hv]adjustment()
 */
#define GTK_HAVE_CONTAINER_FOCUS_ADJUSTMENTS		1-0-1

/* newly exported gtk_signal_init()
 * new gtk_signal_n_emissions*()
 * "signal-name" is now an alias for "signal_name"
 * new gtk_signal_emitv*()
 */
#define GTK_HAVE_SIGNAL_INIT				1-0-2
  
/* Gtk+ 1.1.0 version tag.
 * - new gtk_rc_set_image_loader () to install custom image loaders for rc
 *   files.
 * - GtkAccel groups replaced GtkAcceleratorTables
 * - Gdk supports full crossing event now.
 * - Buttons featur relief styles now.
 * - gdk_rgb_*() functions are in place.
 * - stringified enum values can be queried for enum types now.
 * - new key binding system is in place (GtkBindingSet).
 * - simple algorithm for pattern matching is exported now (GtkPatternSpec).
 */
#define GTK_HAVE_FEATURES_1_1_0				1-1-0

/* Gtk+ 1.1.2 version tag
 * - ctree function name changes
 */
#define GTK_HAVE_FEATURES_1_1_2				1-1-2

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GTK_FEATURES_H__ */
